@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,13 +42,15 @@ Bosnian
    <ja>Hunspell 用ボスニア語辞書</ja>
    <kk>Bosnian dictionary for hunspell</kk>
    <ko>Bosnian dictionary for hunspell</ko>
+   <ku>Bosnian dictionary for hunspell</ku>
    <lt>Bosnian dictionary for hunspell</lt>
    <mk>Bosnian dictionary for hunspell</mk>
    <mr>Bosnian dictionary for hunspell</mr>
    <nb_NO>Bosnian dictionary for hunspell</nb_NO>
    <nb>Bosnisk ordliste for hunspell</nb>
    <nl_BE>Bosnian dictionary for hunspell</nl_BE>
-   <nl>Bosnian dictionary for hunspell</nl>
+   <nl>Bosnisch woordenboek voor hunspell</nl>
+   <or>Bosnian dictionary for hunspell</or>
    <pl>Bosnian dictionary for hunspell</pl>
    <pt_BR>Dicionário Bósnio para o hunspell (corretor ortográfico e analisador morfológico)</pt_BR>
    <pt>Dicionário Bósnio para hunspell</pt>
@@ -56,6 +58,7 @@ Bosnian
    <ru>Bosnian dictionary for hunspell</ru>
    <sk>Bosnian dictionary for hunspell</sk>
    <sl>Bosanski slovar za hunspell</sl>
+   <so>Bosnian dictionary for hunspell</so>
    <sq>Fjalor bosnjisht për hunspell</sq>
    <sr>Bosnian dictionary for hunspell</sr>
    <sv>Bosnisk ordbok för hunspell</sv>
