@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,13 +42,15 @@ Greek_Default_Firefox_esr
    <ja>ギリシャ語版 Firefox ESR</ja>
    <kk>Greek localisation of Firefox ESR</kk>
    <ko>Greek localisation of Firefox ESR</ko>
+   <ku>Greek localisation of Firefox ESR</ku>
    <lt>Greek localisation of Firefox ESR</lt>
    <mk>Greek localisation of Firefox ESR</mk>
    <mr>Greek localisation of Firefox ESR</mr>
    <nb_NO>Greek localisation of Firefox ESR</nb_NO>
    <nb>Gresk lokaltilpassing av Firefox ESR</nb>
    <nl_BE>Greek localisation of Firefox ESR</nl_BE>
-   <nl>Greek localisation of Firefox ESR</nl>
+   <nl>Griekse lokalisatie van Firefox ESR</nl>
+   <or>Greek localisation of Firefox ESR</or>
    <pl>Greek localisation of Firefox ESR</pl>
    <pt_BR>Grego Localização para o Firefox ESR</pt_BR>
    <pt>Grego Localização para Firefox ESR</pt>
@@ -56,6 +58,7 @@ Greek_Default_Firefox_esr
    <ru>Greek localisation of Firefox ESR</ru>
    <sk>Greek localisation of Firefox ESR</sk>
    <sl>Grške krajevne nastavitve za Firefox ESR</sl>
+   <so>Greek localisation of Firefox ESR</so>
    <sq>Përkthimi i Firefox-it ESR në greqisht</sq>
    <sr>Greek localisation of Firefox ESR</sr>
    <sv>Grekisk lokalisering av Firefox ESR</sv>
