@@ -1,4 +1,4 @@
-<?xml version="1.0" encoding="UTF-8"?>
+<?xml version="1.0"?>
 <app>
 
 <category>
@@ -78,12 +78,12 @@ all
 <screenshot>none</screenshot>
 
 <preinstall>
-echo "deb http://deb.debian.org/debian bullseye-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
+echo "deb http://deb.debian.org/debian trixie-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
 apt-get update
 </preinstall>
 
 <install_package_names>
--t bullseye-backports libreoffice-base-core
+-t trixie-backports libreoffice-base-core
 libreoffice-calc
 libreoffice-draw
 libreoffice-impress
@@ -92,7 +92,6 @@ libreoffice-writer
 libreoffice-base
 libreoffice-gtk3
 libreoffice-l10n-lt
-libreoffice-java-common
 </install_package_names>
 
 <postinstall>
@@ -108,7 +107,6 @@ libreoffice-impress
 libreoffice-math
 libreoffice-writer
 libreoffice-base
-libreoffice-java-common
 libreoffice-gtk3
 libreoffice-l10n-lt
 </uninstall_package_names>
