@@ -6,7 +6,7 @@ Desktop Environments
 </category>
 
 <name>
-LXQT
+LXQT with Consolekit
 </name>
 
 <description>
@@ -83,6 +83,8 @@ all
 
 <install_package_names>
 lxqt
+consolekit
+libpam-ck-connector
 </install_package_names>
 
 
@@ -93,5 +95,7 @@ lxqt
 
 <uninstall_package_names>
 lxqt
+consolekit
+libpam-ck-connector
 </uninstall_package_names>
 </app>
